<?php
// no direct access
defined('ABSPATH') || die();

if(!class_exists('LSDR_Theme')):

/**
 * Theme Class
 *
 * @class LSDR_Theme
 * @version	1.0.0
 */
class LSDR_Theme extends LSDR_Base
{
    /**
     * Constructor
     */
    public function __construct()
    {
        parent::__construct();
    }

    public function init()
    {
        add_action('after_setup_theme', array($this, 'setup'));
        add_action('after_setup_theme', array($this, 'content_width'), 0);
		
        add_filter('body_class', array($this, 'body_classes'));
        add_action('wp_head', array($this, 'pingback_header'));
    }
	
    public function setup()
    {
        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');

        /*
         * Let WordPress manage the document title.
         */
        add_theme_support('title-tag');

        /*
         * Enable support for Post Thumbnails on posts and pages.
         */
        add_theme_support('post-thumbnails');

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
            'style',
            'script',
			'navigation-widgets',
        ));

        // Add theme support for selective refresh for widgets.
        add_theme_support('customize-selective-refresh-widgets');

        /**
         * Add support for core custom logo.
         */
        add_theme_support('custom-logo', array(
            'height' => 250,
            'width' => 250,
            'flex-width' => true,
            'flex-height' => true,
        ));
		
		/**
         * Add support for editors style.
         */
		add_theme_support('editor-styles');
		
		/**
         * Add support for block style.
         */
		add_theme_support('wp-block-styles');
		
		/**
         * Add support for responsive embeds.
         */
		add_theme_support('responsive-embeds');
		
		/**
         * Add support for align wide.
         */
		add_theme_support('align-wide');
    }

    public function content_width()
    {
        $GLOBALS['content_width'] = apply_filters('lsdr_content_width', 640); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound
    }

    public function body_classes($classes)
    {
        // Adds a class of hfeed to non-singular pages.
        if(!is_singular()) $classes[] = 'hfeed';

        $header = get_theme_mod('listdomer_header_type', 'type1');
        $footer = get_theme_mod('listdomer_footer_type', 'type1');

        // Single Page
        if(is_singular('page'))
        {
            global $post;

            if($post and isset($post->ID) and $h = get_post_meta($post->ID, 'lsdr_header', true)) $header = $h;
            if($post and isset($post->ID) and $f = get_post_meta($post->ID, 'lsdr_footer', true)) $footer = $f;
        }

        // Header & Footer Type
        $classes[] = 'listdomer-header-'.$header;
        $classes[] = 'listdomer-footer-'.$footer;

        return $classes;
    }

    /**
     * Add a pingback url auto-discovery header for single posts, pages, or attachments.
     */
    public function pingback_header()
    {
        if(is_singular() and pings_open())
        {
            printf('<link rel="pingback" href="%s">', esc_url(get_bloginfo('pingback_url')));
        }
    }

    public static function logo($dark = false)
    {
        if($dark) $logo = LSDR_Theme::get_dark_logo();
        else $logo = get_custom_logo();

        if((is_front_page() or is_home()) and !is_page()) return '<h1 class="site-logo">'.$logo.'</h1>';
        else return '<div class="site-logo">'.$logo.'</div>';
    }

    public static function has_dark_logo()
    {
        return (boolean) get_theme_mod('listdomer_dark_logo');
    }

    public static function get_dark_logo($blog_id = 0)
    {
        $switched_blog = false;
        if(is_multisite() && !empty($blog_id) && get_current_blog_id() !== (int) $blog_id)
        {
            switch_to_blog($blog_id);
            $switched_blog = true;
        }

        $html = '';
        $dark_logo = get_theme_mod('listdomer_dark_logo');

        // We have a logo. Logo is go.
        if($dark_logo)
        {
            $dark_logo_id = attachment_url_to_postid($dark_logo);

            $dark_logo_attr = array(
                'class' => 'custom-logo',
                'loading' => false,
            );

            if(is_front_page() && !is_paged())
            {
                /*
                 * If on the home page, set the logo alt attribute to an empty string,
                 * as the image is decorative and doesn't need its purpose to be described.
                 */
                $dark_logo_attr['alt'] = '';
            }
            else
            {
                /*
                 * If the logo alt attribute is empty, get the site title and explicitly pass it
                 * to the attributes used by wp_get_attachment_image().
                 */
                $image_alt = get_post_meta($dark_logo_id, '_wp_attachment_image_alt', true);
                if(empty($image_alt)) $dark_logo_attr['alt'] = get_bloginfo('name', 'display');
            }

            /**
             * Filters the list of custom logo image attributes.
             *
             * @since 5.5.0
             *
             * @param array $custom_logo_attr Custom logo image attributes.
             * @param int   $custom_logo_id   Custom logo attachment ID.
             * @param int   $blog_id          ID of the blog to get the custom logo for.
             */
            $dark_logo_attr = apply_filters('get_custom_logo_image_attributes', $dark_logo_attr, $dark_logo_id, $blog_id);

            /*
             * If the alt attribute is not empty, there's no need to explicitly pass it
             * because wp_get_attachment_image() already adds the alt attribute.
             */
            $image = wp_get_attachment_image($dark_logo_id, 'full', false, $dark_logo_attr);

            if(is_front_page() && !is_paged())
            {
                // If on the home page, don't link the logo to home.
                $html = sprintf('<span class="custom-logo-link">%1$s</span>', $image);
            }
            else
            {
                $aria_current = is_front_page() && !is_paged() ? ' aria-current="page"' : '';
                $html = sprintf('<a href="%1$s" class="custom-logo-link" rel="home"%2$s>%3$s</a>', esc_url(home_url('/')), $aria_current, $image);
            }
        }
        elseif(is_customize_preview())
        {
            // If no logo is set but we're in the Customizer, leave a placeholder (needed for the live preview).
            $html = sprintf('<a href="%1$s" class="custom-logo-link" style="display:none;"><img class="custom-logo" alt="" /></a>', esc_url(home_url('/')));
        }

        // Switch Back
        if($switched_blog) restore_current_blog();

        return $html;
    }
}

endif;